.. _tutorial-simple:

===================================
Part 1: Writting your first feature
===================================

Welcome to the first part of Lettuce tutorials, through this tutorial
we will use Lettuce to provide a simple and pythonic way to create a
tests for a python module.

To keep following the tutorial, you must:

    * have already :ref:`installed <intro-install>` Lettuce.
    * have a unix shell available.
